Rev 2632: Fix format strings in file:///home/pqm/archives/thelove/bzr/%2Btrunk/

Canonical.com Patch Queue Manager pqm at pqm.ubuntu.com
Thu Jul 19 21:23:09 BST 2007


At file:///home/pqm/archives/thelove/bzr/%2Btrunk/

------------------------------------------------------------
revno: 2632
revision-id: pqm at pqm.ubuntu.com-20070719202307-rr3ky8d16z5v7h3e
parent: pqm at pqm.ubuntu.com-20070719160934-d51fyijw69oto88p
parent: abentley at panoramicfeedback.com-20070719181611-etp4itjrl2tci9kl
committer: Canonical.com Patch Queue Manager <pqm at pqm.ubuntu.com>
branch nick: +trunk
timestamp: Thu 2007-07-19 21:23:07 +0100
message:
  Fix format strings
modified:
  bzrlib/bundle/serializer/__init__.py __init__.py-20051118175413-86b97db0b618feef
  bzrlib/merge_directive.py      merge_directive.py-20070228184838-ja62280spt1g7f4x-1
  bzrlib/tests/blackbox/test_merge_directive.py test_merge_directive-20070302012039-zh7uhy39biairtn0-1
  bzrlib/tests/test_bundle.py    test.py-20050630184834-092aa401ab9f039c
  bzrlib/tests/test_merge_directive.py test_merge_directive-20070228184838-ja62280spt1g7f4x-2
    ------------------------------------------------------------
    revno: 2520.4.136
    merged: abentley at panoramicfeedback.com-20070719181611-etp4itjrl2tci9kl
    parent: abentley at panoramicfeedback.com-20070719150323-o7nd8emdqg44hj66
    committer: Aaron Bentley <abentley at panoramicfeedback.com>
    branch nick: bzr.mpbundle
    timestamp: Thu 2007-07-19 14:16:11 -0400
    message:
      Fix format strings
=== modified file 'bzrlib/bundle/serializer/__init__.py'
--- a/bzrlib/bundle/serializer/__init__.py	2007-07-17 13:27:14 +0000
+++ b/bzrlib/bundle/serializer/__init__.py	2007-07-19 18:16:11 +0000
@@ -38,7 +38,7 @@
 
 _serializers = {}
 
-v4_string = '4alpha'
+v4_string = '4'
 
 def _get_bundle_header(version):
     return '%s%s\n' % (BUNDLE_HEADER, version)

=== modified file 'bzrlib/merge_directive.py'
--- a/bzrlib/merge_directive.py	2007-07-03 22:44:19 +0000
+++ b/bzrlib/merge_directive.py	2007-07-19 18:16:11 +0000
@@ -328,7 +328,7 @@
 
 class MergeDirective2(_BaseMergeDirective):
 
-    _format_string = 'Bazaar merge directive format 2 (Bazaar 0.18)'
+    _format_string = 'Bazaar merge directive format 2 (Bazaar 0.19)'
 
     def __init__(self, revision_id, testament_sha1, time, timezone,
                  target_branch, patch=None, source_branch=None, message=None,

=== modified file 'bzrlib/tests/blackbox/test_merge_directive.py'
--- a/bzrlib/tests/blackbox/test_merge_directive.py	2007-07-17 13:27:14 +0000
+++ b/bzrlib/tests/blackbox/test_merge_directive.py	2007-07-19 18:16:11 +0000
@@ -29,7 +29,7 @@
 From: J. Random Hacker <jrandom at example.com>
 Subject: bar
 
-# Bazaar merge directive format 2 \\(Bazaar 0.18\\)
+# Bazaar merge directive format 2 \\(Bazaar 0.19\\)
 # revision_id: bar-id
 # target_branch: ../tree2
 # testament_sha1: .*

=== modified file 'bzrlib/tests/test_bundle.py'
--- a/bzrlib/tests/test_bundle.py	2007-07-17 13:27:14 +0000
+++ b/bzrlib/tests/test_bundle.py	2007-07-19 18:16:11 +0000
@@ -1208,7 +1208,7 @@
 
 class V4BundleTester(BundleTester, TestCaseWithTransport):
 
-    format = '4alpha'
+    format = '4'
 
     def get_valid_bundle(self, base_rev_id, rev_id, checkout_dir=None):
         """Create a bundle from base_rev_id -> rev_id in built-in branch.
@@ -1255,7 +1255,7 @@
                                     '<file executable="y" file_id="exe-1"')
         new_text = new_text.replace('B372', 'B387')
         bundle_txt = StringIO()
-        bundle_txt.write(serializer._get_bundle_header('4alpha'))
+        bundle_txt.write(serializer._get_bundle_header('4'))
         bundle_txt.write('\n')
         bundle_txt.write(new_text.encode('bz2'))
         bundle_txt.seek(0)
@@ -1338,7 +1338,7 @@
         tree_b = self.make_branch_and_tree('tree_b')
         repo_b = tree_b.branch.repository
         s = StringIO()
-        serializer = BundleSerializerV4('4alpha')
+        serializer = BundleSerializerV4('4')
         serializer.write(tree_a.branch.repository, ['A', 'B'], {}, s)
         s.seek(0)
         install_bundle(repo_b, serializer.read(s))
@@ -1448,7 +1448,7 @@
 
 class MungedBundleTesterV4(TestCaseWithTransport, MungedBundleTester):
 
-    format = '4alpha'
+    format = '4'
 
 
 class TestBundleWriterReader(TestCase):

=== modified file 'bzrlib/tests/test_merge_directive.py'
--- a/bzrlib/tests/test_merge_directive.py	2007-07-03 22:44:19 +0000
+++ b/bzrlib/tests/test_merge_directive.py	2007-07-19 18:16:11 +0000
@@ -31,7 +31,7 @@
 #\x20
 booga"""
 
-OUTPUT1_2 = """# Bazaar merge directive format 2 (Bazaar 0.18)
+OUTPUT1_2 = """# Bazaar merge directive format 2 (Bazaar 0.19)
 # revision_id: example:
 # target_branch: http://example.com
 # testament_sha1: sha
@@ -51,7 +51,7 @@
 #\x20
 booga"""
 
-OUTPUT2_2 = """# Bazaar merge directive format 2 (Bazaar 0.18)
+OUTPUT2_2 = """# Bazaar merge directive format 2 (Bazaar 0.19)
 # revision_id: example:
 # target_branch: http://example.com
 # testament_sha1: sha
@@ -96,7 +96,7 @@
 
 Aaron
 
 # Bazaar merge directive format 2 (Bazaar 0.18)\r
 # revision_id: example:
 # target_branch: http://example.com
 # testament_sha1: sha
@@ -268,7 +268,7 @@
 From: J. Random Hacker <jrandom at example.com>
 Subject: Commit of rev2a
 
 # Bazaar merge directive format 2 \\(Bazaar 0.18\\)
 # revision_id: rev2a
 # target_branch: (.|\n)*
 # testament_sha1: .*
@@ -294,7 +294,7 @@
 From: J. Random Hacker <jrandom at example.com>
 Subject: Commit of rev2a with special message
 
 # Bazaar merge directive format 2 \\(Bazaar 0.18\\)
 # revision_id: rev2a
 # target_branch: (.|\n)*
 # testament_sha1: .*
@@ -96,7 +96,7 @@
 Aaron
 
-# Bazaar merge directive format 2 (Bazaar 0.18)\r
+# Bazaar merge directive format 2 (Bazaar 0.19)\r
 # revision_id: example:
 # target_branch: http://example.com
@@ -268,7 +268,7 @@
 Subject: Commit of rev2a
 
-# Bazaar merge directive format 2 \\(Bazaar 0.18\\)
+# Bazaar merge directive format 2 \\(Bazaar 0.19\\)
 # revision_id: rev2a
 # target_branch: (.|\n)*
@@ -294,7 +294,7 @@
 Subject: Commit of rev2a with special message
 
-# Bazaar merge directive format 2 \\(Bazaar 0.18\\)
+# Bazaar merge directive format 2 \\(Bazaar 0.19\\)
 # revision_id: rev2a
 # target_branch: (.|\n)*




More information about the bazaar-commits mailing list